<?php
/**
 * Connexion à la base de donnée
 */
function connexion_bd($config) {
	$connexion = new PDO($config['sgbd'].':host='.$config['host'].';dbname='.$config['base'], $config['user'], $config['passwd'], array(PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8')) ;
	$connexion->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION) ;
	return $connexion ;
}

function file_read($fichier, $acces) {
	$contenu = "" ;
	if (file_exists($fichier)) {
		$open = fopen($fichier, $acces) ;
		if ($open) {
			while (!feof($open)) {
				$buffer = fgets($open, 2048) ;
				//$this->contenu->Add($buffer->GetValue()) ;
				$contenu = $contenu.$buffer ;
			}
			fclose($open) ;
		}
	}
	return $contenu ;
}

// Ajoute un élément au tableau
function array_add($tab, $element) {
	$taille = sizeof($tab) ;
	$tab[$taille] = $element ;
	return $tab ;
}

/**
 * Moteur de templates HTML
 */
function template_html($template, $vars_o=null, $stream=false) {
	// Récupère le contenu du Template
	if ($stream == false) {
		$contenu = file_read($template, "r") ;
	} else {
		$contenu = $template ;
	}
	// Initialise le tableau des variables
	$vars = array() ;
	$debut = 0 ;
	// Boucle pour rechercher toutes les variables dans le template
	while ($debut < strlen($contenu) && $debut < strpos($contenu, "{", $debut+1)) {
		$debut = strpos($contenu, "{", $debut+1) ;
		$fin = strpos($contenu, "}", $debut+1) ;
		$var = substr($contenu, $debut+1, $fin-$debut-1) ;
		// Ajoute la variable au tableau
		$vars = array_add($vars, $var) ;
		$debut = $fin ;
	}
	$html = $contenu ;
	// Boucle pour remplacer les variables par leurs valeurs
	foreach ($vars as $var) {
		$mot = "{".$var."}" ;
		if (isset($vars_o[$var])) {
			$replace = $vars_o[$var] ;
		} else {
			if (strstr($var, "LANG_")) {
				$replace = $mot ;
			} else {
				$replace = "INC" ;
			}
		}
		$html = str_replace($mot, $replace, $html) ;
	}
	return $html ;
}

/**
 * Retourne true si l'utilisateur est membre de  l'espace de travail
 */
function Lanthane_C_utilisateur_membre_edt_($connex, $id_u, $id_edt) {
	$res = false ;
	$edts = Lanthane_BDD_espace_de_travail_select_id_utilisateur($connex, $id_u) ;
	
	foreach ($edts as $edt) {
		if ($edt[0] == $id_edt) {
			$res = true ;
		}
	}
    return $res ;
}

/**
 * Formate correctement le tableau $_FILES
 */
function Lanthane_C_format_fichiers($fichiers) {
	$fichiers_f = array() ;
	
	// Nombre de fichiers
	$n_fichiers = sizeof($fichiers["fichiers"]["name"]) ;
	
	for ($c = 0 ; $c <= ($n_fichiers - 1) ; $c++) {
		$fichiers_f[$c]["nom"] = $fichiers["fichiers"]["name"][$c] ;
		$fichiers_f[$c]["type"] = $fichiers["fichiers"]["type"][$c] ;
		$fichiers_f[$c]["tmp"] = $fichiers["fichiers"]["tmp_name"][$c] ;
		$fichiers_f[$c]["taille"] = $fichiers["fichiers"]["size"][$c] ;
		$fichiers_f[$c]["erreur"] = $fichiers["fichiers"]["error"][$c] ;
	}
	
	return $fichiers_f ;
}

function Lanthane_C_explore($connex, $id_u, $id_edt, $chemin) {
	$dossiers = "" ;
	$fichiers = "" ;
	
	if ($chemin != "/") {
		$reptmp = explode("/", $chemin) ;
        array_pop($reptmp) ;
        array_pop($reptmp) ;
        $rep_haut = implode("/", $reptmp) . "/" ;
	} else {
		$rep_haut = $chemin ;
	}
	
	$html = template_html("templates/explorateur.html", array("id_edt" => $id_edt, "chemin" => $chemin, "lien_haut" => "<p><a href=\"index.php?route=profil&section=explore&edt=" . $id_edt . "&chemin=" . $rep_haut . "\">" . $rep_haut . "</a></p>")) ;
	
	// Recherche tous les fichiers dans la base de données
	$fichiers_bdd = Lanthane_BDD_fichier_select_id_espace_de_travail_emplacement($connex, $id_edt, $chemin) ;
	
	foreach (glob("fichiers/EDT/edt_" . $id_edt . $chemin . "*") as $fichier) {
		$nom_fichier = array_reverse(explode("/", $fichier))[0] ;
        $vars["chemin"] = $chemin . array_reverse(explode("/", $fichier))[0] . "/" ;
        $vars["id_edt"] = $id_edt ;
        $vars["nom"] = $nom_fichier ;
		if (is_dir($fichier)) {
			$dossiers = $dossiers . template_html("templates/dossier.html", $vars) ;
		} else {
			// Cherche la concordance entre les fichiers présent sur le système de fichier
			// et ceux présents dans la base de données
			foreach ($fichiers_bdd as $fichier_bdd) {
				if ($fichier_bdd[1] == $nom_fichier) {
					// Type du fichier si extension
					if (strpos(".", $nom_fichier) != false) {
					    $vars["type"] = explode(".", $nom_fichier)[1] ;
				    }
					$vars["id"] = $fichier_bdd[0] ;
                    $fichiers = $fichiers . template_html("templates/fichier.html", $vars) ;
			    }
            }
		}
	}
	return $html . $dossiers . $fichiers ;
}

function Lanthane_C_nom_fichier($fichier) {
	$tab = explode("/", $fichier) ;
	$nom = $tab[sizeof($tab)-1] ;
	return $nom ;
}

function Lanthane_C_http_force_telechargement($nom, $situation, $poids) {
	header('Content-Type: application/octet-stream') ;
	header('Content-Length: '.filesize($situation)) ;
	header('Content-disposition: attachment; filename='.$nom) ;
	header('Pragma: no-cache') ;
	header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0') ;
	header('Expires: 0') ;
	readfile($situation) ;
}
?>
